#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlets.html.interfaces import IRawPortletSettings, IHTMLPortletSettings
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_PERMISSION

# import packages
from pyams_portal.portlet import PortletSettings, portlet_config, Portlet, PortletRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from zope.interface import implementer, Interface
from zope.schema.fieldproperty import FieldProperty

from pyams_portal import _


#
# Raw HTML code portlet
#

RAW_PORTLET_NAME = 'pyams_portal.portlet.raw'


@implementer(IRawPortletSettings)
class RawPortletSettings(PortletSettings):
    """Raw HTML code portlet settings"""

    body = FieldProperty(IRawPortletSettings['body'])


@portlet_config(permission=VIEW_PERMISSION)
class RawPortlet(Portlet):
    """Raw HTML code portlet"""

    name = RAW_PORTLET_NAME
    label = _("Raw HTML")

    toolbar_css_class = 'fa fa-fw fa-2x fa-code'

    settings_class = RawPortletSettings


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IRawPortletSettings), provides=IPortletRenderer)
@template_config(template='html.pt', layer=IPyAMSLayer)
class RawPortletDefaultRenderer(PortletRenderer):
    """Raw HTML portlet renderer"""

    label = _("Default code renderer")


#
# Rich text portlet
#

HTML_PORTLET_NAME = 'pyams_portal.portlet.html'


@implementer(IHTMLPortletSettings)
class HTMLPortletSettings(PortletSettings):
    """Rich text portlet settings"""

    body = FieldProperty(IHTMLPortletSettings['body'])


@portlet_config(permission=VIEW_PERMISSION)
class HTMLPortlet(Portlet):
    """Rich text portlet"""

    name = HTML_PORTLET_NAME
    label = _("Rich text")

    toolbar_css_class = 'fa fa-fw fa-2x fa-html5'

    settings_class = HTMLPortletSettings


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IHTMLPortletSettings), provides=IPortletRenderer)
@template_config(template='html.pt', layer=IPyAMSLayer)
class HTMLPortletDefaultRenderer(PortletRenderer):
    """Rich text portlet renderer"""

    label = _("Default text renderer")
